from .charsearch import *
from .aninews import *

'''
An unofficial API to get data about anime characters, anime news and more.
'''

__author__ = "DriftAsimov"
__title__ = "animec"
__copyright__ = "Copyright Drift Asimov 2021"
__version__ = "0.0.71"
__license__ = "MIT"